@@ -1,32 +1,32 @@
 /***************************************************************************
-*   Copyright (C) 2007-2014 Lukas Appelhans <l.appelhans@gmx.de>          *
-*   Copyright (C) 2008 Dario Freddi <drf54321@gmail.com>                  *
-*   Copyright (C) 2010 Matthias Fuchs <mat69@gmx.net>                     *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
-***************************************************************************/
+ *   Copyright (C) 2007-2014 Lukas Appelhans <l.appelhans@gmx.de>          *
+ *   Copyright (C) 2008 Dario Freddi <drf54321@gmail.com>                  *
+ *   Copyright (C) 2010 Matthias Fuchs <mat69@gmx.net>                     *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+ ***************************************************************************/
 
 #include "urlchecker.h"
-#include "urlchecker_p.h"
-#include "mainwindow.h"
 #include "core/filedeleter.h"
 #include "core/kget.h"
 #include "core/transferhandler.h"
 #include "core/transfertreemodel.h"
+#include "mainwindow.h"
 #include "settings.h"
+#include "urlchecker_p.h"
 
 #include <algorithm>
 #include <boost/bind/bind.hpp>
@@ -34,8 +34,8 @@
 #include "kget_debug.h"
 
 #include <QCheckBox>
-#include <QFileInfo>
 #include <QDialogButtonBox>
+#include <QFileInfo>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
@@ -46,7 +46,7 @@
 #include <KStandardGuiItem>
 
 ExistingTransferDialog::ExistingTransferDialog(const QString &text, const QString &caption, QWidget *parent)
-  : QDialog(parent)
+    : QDialog(parent)
 {
     setWindowTitle(caption.isEmpty() ? i18n("Question") : caption);
     setModal(true);
@@ -69,7 +69,7 @@ ExistingTransferDialog::ExistingTransferDialog(const QString &text, const QStrin
     connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &ExistingTransferDialog::slotCancelClicked);
     bottomLayout->addWidget(buttonBox);
     layout->addLayout(bottomLayout, 0);
-    
+
     setLayout(layout);
 }
 
@@ -88,13 +88,12 @@ void ExistingTransferDialog::slotCancelClicked()
     done(Cancel);
 }
 
-
 UrlChecker::UrlChecker(UrlType type)
-  : m_type(type),
-    m_cancel(false),
-    m_overwriteAll(false),
-    m_autoRenameAll(false),
-    m_skipAll(false)
+    : m_type(type)
+    , m_cancel(false)
+    , m_overwriteAll(false)
+    , m_autoRenameAll(false)
+    , m_skipAll(false)
 {
 }
 
@@ -102,10 +101,9 @@ UrlChecker::~UrlChecker()
 {
 }
 
-///Static methods following
+/// Static methods following
 
-struct lessThan
-{
+struct lessThan {
     bool operator()(const QUrl &lhs, const QUrl &rhs) const
     {
         return lhs.url() < rhs.url();
@@ -114,20 +112,23 @@ struct lessThan
 
 void UrlChecker::removeDuplicates(QList<QUrl> &urls)
 {
-    std::sort(urls.begin(), urls.end(), lessThan());//sort the urls, to find duplicates fast
-    urls.erase(std::unique(urls.begin(), urls.end(),
-               boost::bind(&QUrl::matches, boost::placeholders::_1, boost::placeholders::_2, QUrl::StripTrailingSlash | QUrl::NormalizePathSegments)), urls.end());
+    std::sort(urls.begin(), urls.end(), lessThan()); // sort the urls, to find duplicates fast
+    urls.erase(
+        std::unique(urls.begin(),
+                    urls.end(),
+                    boost::bind(&QUrl::matches, boost::placeholders::_1, boost::placeholders::_2, QUrl::StripTrailingSlash | QUrl::NormalizePathSegments)),
+        urls.end());
 }
 
 UrlChecker::UrlError UrlChecker::checkUrl(const QUrl &url, const UrlChecker::UrlType type, bool showNotification)
 {
     switch (type) {
-        case Source:
-            return checkSource(url, showNotification);
-        case Destination:
-            return checkDestination(url, showNotification);
-        case Folder:
-            return checkFolder(url, showNotification);
+    case Source:
+        return checkSource(url, showNotification);
+    case Destination:
+        return checkDestination(url, showNotification);
+    case Folder:
+        return checkFolder(url, showNotification);
     }
 
     return NoError;
@@ -140,7 +141,7 @@ bool UrlChecker::wouldOverwrite(const QUrl &source, const QUrl &dest)
 
 UrlChecker::UrlError UrlChecker::checkSource(const QUrl &src, bool showNotification)
 {
-    //NOTE hasPath is not used, as this would disallow addresses like https://www.kde.org/ as there is no path
+    // NOTE hasPath is not used, as this would disallow addresses like https://www.kde.org/ as there is no path
     UrlError error = NoError;
     if (src.isEmpty()) {
         return Empty;
@@ -148,7 +149,7 @@ UrlChecker::UrlError UrlChecker::checkSource(const QUrl &src, bool showNotificat
     if ((error == NoError) && !src.isValid()) {
         error = Invalid;
     }
-    if ((error == NoError) && src.scheme().isEmpty()){
+    if ((error == NoError) && src.scheme().isEmpty()) {
         error = NoProtocol;
     }
     /*if ((error == NoError) && !src.hasHost()) {//FIXME deactivated to allow file://....metalink etc
@@ -160,7 +161,7 @@ UrlChecker::UrlError UrlChecker::checkSource(const QUrl &src, bool showNotificat
         KGet::showNotification(KGet::m_mainWindow, "error", message(src, Source, error));
     }
 
-    //TODO also check sourceUrl.url() != QUrl(sourceUrl.url()).fileName() as in NewTransferDialog::setSource?
+    // TODO also check sourceUrl.url() != QUrl(sourceUrl.url()).fileName() as in NewTransferDialog::setSource?
 
     return error;
 }
@@ -174,7 +175,7 @@ UrlChecker::UrlError UrlChecker::checkDestination(const QUrl &destination, bool
     }
 
     if (error == NoError) {
-        //not supposed to be a folder
+        // not supposed to be a folder
         QFileInfo fileInfo(destination.toLocalFile());
         if (!destination.isValid() || fileInfo.isDir()) {
             error = Invalid;
@@ -185,7 +186,7 @@ UrlChecker::UrlError UrlChecker::checkDestination(const QUrl &destination, bool
             error = NotWriteable;
         }
     }
-        
+
     qCDebug(KGET_DEBUG) << "Destination:" << destination << "has error:" << error;
 
     if (showNotification && (error != NoError)) {
@@ -195,7 +196,6 @@ UrlChecker::UrlError UrlChecker::checkDestination(const QUrl &destination, bool
     return error;
 }
 
-
 UrlChecker::UrlError UrlChecker::checkFolder(const QUrl &folder, bool showNotification)
 {
     UrlError error = NoError;
@@ -206,13 +206,13 @@ UrlChecker::UrlError UrlChecker::checkFolder(const QUrl &folder, bool showNotifi
     }
 
     if (error == NoError) {
-        //has to be a folder
+        // has to be a folder
         QFileInfo fileInfo(destDir);
         if (!folder.isValid() || !fileInfo.isDir()) {
             error = Invalid;
         }
 
-        //has to be writeable
+        // has to be writeable
         if ((error == NoError) && !fileInfo.isWritable()) {
             error = NotWriteable;
         }
@@ -234,7 +234,8 @@ QUrl UrlChecker::destUrl(const QUrl &destOrFolder, const QUrl &source, const QSt
         if (usedFileName.isEmpty()) {
             usedFileName = QUrl::toPercentEncoding(source.toString(), "/");
         }
-        if (!dest.path().endsWith('/')) dest.setPath(dest.path() + '/');
+        if (!dest.path().endsWith('/'))
+            dest.setPath(dest.path() + '/');
         dest.setPath(dest.adjusted(QUrl::RemoveFilename).path() + usedFileName);
     } else if (!fileName.isEmpty()) {
         dest.setPath(dest.adjusted(QUrl::RemoveFilename).path() + fileName);
@@ -250,12 +251,12 @@ TransferHandler *UrlChecker::existingTransfer(const QUrl &url, const UrlChecker:
     warn = NoWarning;
 
     switch (type) {
-        case Source:
-            return existingSource(url, warn);
-        case Destination:
-            return existingDestination(url, warn);
-        default:
-            return nullptr;
+    case Source:
+        return existingSource(url, warn);
+    case Destination:
+        return existingDestination(url, warn);
+    default:
+        return nullptr;
     }
 }
 
@@ -290,86 +291,85 @@ TransferHandler *UrlChecker::existingDestination(const QUrl &url, UrlChecker::Ur
     return (transfer ? transfer->handler() : nullptr);
 }
 
-
 QString UrlChecker::message(const QUrl &url, const UrlChecker::UrlType type, const UrlChecker::UrlError error)
 {
     if (url.isEmpty()) {
         if (type == Folder) {
             switch (error) {
-                case Empty:
-                    return i18n("No download directory specified.");
-                case Invalid:
-                    return i18n("Invalid download directory specified.");
-                case NotWriteable:
-                    return i18n("Download directory is not writeable.");
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No download directory specified.");
+            case Invalid:
+                return i18n("Invalid download directory specified.");
+            case NotWriteable:
+                return i18n("Download directory is not writeable.");
+            default:
+                return QString();
             }
         }
         if (type == Destination) {
             switch (error) {
-                case Empty:
-                    return i18n("No download destination specified.");
-                case Invalid:
-                    return i18n("Invalid download destination specified.");
-                case NotWriteable:
-                    return i18n("Download destination is not writeable.");
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No download destination specified.");
+            case Invalid:
+                return i18n("Invalid download destination specified.");
+            case NotWriteable:
+                return i18n("Download destination is not writeable.");
+            default:
+                return QString();
             }
         }
         if (type == Source) {
             switch (error) {
-                case Empty:
-                    return i18n("No URL specified.");
-                case Invalid:
-                    return i18n("Malformed URL.");
-                case NoProtocol:
-                    return i18n("Malformed URL, protocol missing.");
-                case NoHost:
-                    return i18n("Malformed URL, host missing.");
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No URL specified.");
+            case Invalid:
+                return i18n("Malformed URL.");
+            case NoProtocol:
+                return i18n("Malformed URL, protocol missing.");
+            case NoHost:
+                return i18n("Malformed URL, host missing.");
+            default:
+                return QString();
             }
         }
     } else {
         const QString urlString = url.toString();
         if (type == Folder) {
             switch (error) {
-                case Empty:
-                    return i18n("No download directory specified.");
-                case Invalid:
-                    return i18n("Invalid download directory specified:\n%1", urlString);
-                case NotWriteable:
-                    return i18n("Download directory is not writeable:\n%1", urlString);
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No download directory specified.");
+            case Invalid:
+                return i18n("Invalid download directory specified:\n%1", urlString);
+            case NotWriteable:
+                return i18n("Download directory is not writeable:\n%1", urlString);
+            default:
+                return QString();
             }
         }
         if (type == Destination) {
             switch (error) {
-                case Empty:
-                    return i18n("No download destination specified.");
-                case Invalid:
-                    return i18n("Invalid download destination specified:\n%1", urlString);
-                case NotWriteable:
-                    return i18n("Download destination is not writeable:\n%1", urlString);
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No download destination specified.");
+            case Invalid:
+                return i18n("Invalid download destination specified:\n%1", urlString);
+            case NotWriteable:
+                return i18n("Download destination is not writeable:\n%1", urlString);
+            default:
+                return QString();
             }
         }
         if (type == Source) {
             switch (error) {
-                case Empty:
-                    return i18n("No URL specified.");
-                case Invalid:
-                    return i18n("Malformed URL:\n%1", urlString);
-                case NoProtocol:
-                    return i18n("Malformed URL, protocol missing:\n%1", urlString);
-                case NoHost:
-                    return i18n("Malformed URL, host missing:\n%1", urlString);
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No URL specified.");
+            case Invalid:
+                return i18n("Malformed URL:\n%1", urlString);
+            case NoProtocol:
+                return i18n("Malformed URL, protocol missing:\n%1", urlString);
+            case NoHost:
+                return i18n("Malformed URL, host missing:\n%1", urlString);
+            default:
+                return QString();
             }
         }
     }
@@ -382,50 +382,50 @@ QString UrlChecker::message(const QUrl &url, const UrlChecker::UrlType type, con
     if (url.isEmpty()) {
         if (type == Destination) {
             switch (warning) {
-                case ExistingFile:
-                    return i18n("File already exists. Overwrite it?");
-                case ExistingFinishedTransfer:
-                    return i18n("You have already downloaded that file from another location.\nDownload and delete the previous one?");
-                case ExistingTransfer:
-                    return i18n("You are already downloading that file from another location.\nDownload and delete the previous one?");
-                default:
-                    return QString();
+            case ExistingFile:
+                return i18n("File already exists. Overwrite it?");
+            case ExistingFinishedTransfer:
+                return i18n("You have already downloaded that file from another location.\nDownload and delete the previous one?");
+            case ExistingTransfer:
+                return i18n("You are already downloading that file from another location.\nDownload and delete the previous one?");
+            default:
+                return QString();
             }
         }
         if (type == Source) {
             switch (warning) {
-                case ExistingFile:
-                    return i18n("File already exists. Overwrite it?");
-                case ExistingFinishedTransfer:
-                    return i18n("You have already completed a download from that location. Download it again?");
-                case ExistingTransfer:
-                    return i18n("You have a download in progress from that location.\nDelete it and download again?");
-                default:
-                    return QString();
+            case ExistingFile:
+                return i18n("File already exists. Overwrite it?");
+            case ExistingFinishedTransfer:
+                return i18n("You have already completed a download from that location. Download it again?");
+            case ExistingTransfer:
+                return i18n("You have a download in progress from that location.\nDelete it and download again?");
+            default:
+                return QString();
             }
         }
     } else {
         const QString urlString = url.toString();
         if (type == Destination) {
             switch (warning) {
-                case ExistingFile:
-                    return i18n("File already exists:\n%1\nOverwrite it?", urlString);
-                case ExistingFinishedTransfer:
-                    return i18n("You have already downloaded that file from another location.\nDownload and delete the previous one?");
-                case ExistingTransfer:
-                    return i18n("You are already downloading that file from another location.\nDownload and delete the previous one?");
-                default:
-                    return QString();
+            case ExistingFile:
+                return i18n("File already exists:\n%1\nOverwrite it?", urlString);
+            case ExistingFinishedTransfer:
+                return i18n("You have already downloaded that file from another location.\nDownload and delete the previous one?");
+            case ExistingTransfer:
+                return i18n("You are already downloading that file from another location.\nDownload and delete the previous one?");
+            default:
+                return QString();
             }
         }
         if (type == Source) {
             switch (warning) {
-                case ExistingFinishedTransfer:
-                    return i18n("You have already completed a download from the location: \n\n%1\n\nDownload it again?", urlString);
-                case ExistingTransfer:
-                    return i18n("You have a download in progress from the location: \n\n%1\n\nDelete it and download again?", urlString);
-                default:
-                    return QString();
+            case ExistingFinishedTransfer:
+                return i18n("You have already completed a download from the location: \n\n%1\n\nDownload it again?", urlString);
+            case ExistingTransfer:
+                return i18n("You have a download in progress from the location: \n\n%1\n\nDelete it and download again?", urlString);
+            default:
+                return QString();
             }
         }
     }
@@ -450,32 +450,32 @@ QString UrlChecker::message(const QList<QUrl> &urls, const UrlChecker::UrlType t
         }
         if (type == Source) {
             switch (error) {
-                case Empty:
-                    return i18n("No URL specified.");
-                case Invalid:
-                    return i18n("Malformed URLs.");
-                case NoProtocol:
-                    return i18n("Malformed URLs, protocol missing.");
-                case NoHost:
-                    return i18n("Malformed URLs, host missing.");
-                default:
-                    return QString();
+            case Empty:
+                return i18n("No URL specified.");
+            case Invalid:
+                return i18n("Malformed URLs.");
+            case NoProtocol:
+                return i18n("Malformed URLs, protocol missing.");
+            case NoHost:
+                return i18n("Malformed URLs, host missing.");
+            default:
+                return QString();
             }
         }
     } else {
         switch (error) {
-            case Empty:
-                return i18n("No URL specified.");
-            case Invalid:
-                return i18n("Malformed URLs:\n%1", urlsString);
-            case NoProtocol:
-                return i18n("Malformed URLs, protocol missing:\n%1", urlsString);
-            case NoHost:
-                return i18n("Malformed URLs, host missing:\n%1", urlsString);
-            case NotWriteable:
-                return i18n("Destinations are not writable:\n%1", urlsString);
-            default:
-                return QString();
+        case Empty:
+            return i18n("No URL specified.");
+        case Invalid:
+            return i18n("Malformed URLs:\n%1", urlsString);
+        case NoProtocol:
+            return i18n("Malformed URLs, protocol missing:\n%1", urlsString);
+        case NoHost:
+            return i18n("Malformed URLs, host missing:\n%1", urlsString);
+        case NotWriteable:
+            return i18n("Destinations are not writable:\n%1", urlsString);
+        default:
+            return QString();
         }
     }
 
@@ -496,47 +496,47 @@ QString UrlChecker::message(const QList<QUrl> &urls, const UrlChecker::UrlType t
     if (urls.isEmpty()) {
         if (type == Destination) {
             switch (warning) {
-                case ExistingFile:
-                    return i18n("Files exist already. Overwrite them?");
-                case ExistingFinishedTransfer:
-                    return i18n("You have already completed downloads at those destinations. Download them again?");
-                case ExistingTransfer:
-                    return i18n("You have downloads in progress to these destinations.\nDelete them and download again?");
-                default:
-                    return QString();
+            case ExistingFile:
+                return i18n("Files exist already. Overwrite them?");
+            case ExistingFinishedTransfer:
+                return i18n("You have already completed downloads at those destinations. Download them again?");
+            case ExistingTransfer:
+                return i18n("You have downloads in progress to these destinations.\nDelete them and download again?");
+            default:
+                return QString();
             }
         }
         if (type == Source) {
             switch (warning) {
-                case ExistingFinishedTransfer:
-                    return i18n("You have already completed downloads from these locations. Download them again?");
-                case ExistingTransfer:
-                    return i18n("You have downloads in progress from these locations.\nDelete them and download again?");
-                default:
-                    return QString();
+            case ExistingFinishedTransfer:
+                return i18n("You have already completed downloads from these locations. Download them again?");
+            case ExistingTransfer:
+                return i18n("You have downloads in progress from these locations.\nDelete them and download again?");
+            default:
+                return QString();
             }
         }
     } else {
         if (type == Destination) {
             switch (warning) {
-                case ExistingFile:
-                    return i18n("Files exist already:\n%1\nOverwrite them?", urlsString);
-                case ExistingFinishedTransfer:
-                    return i18n("You have already completed downloads at those destinations: \n\n%1\n\n Download them again?", urlsString);
-                case ExistingTransfer:
-                    return i18n("You have downloads in progress to these destinations: \n\n%1\n\nDelete them and download again?", urlsString);
-                default:
-                    return QString();
+            case ExistingFile:
+                return i18n("Files exist already:\n%1\nOverwrite them?", urlsString);
+            case ExistingFinishedTransfer:
+                return i18n("You have already completed downloads at those destinations: \n\n%1\n\n Download them again?", urlsString);
+            case ExistingTransfer:
+                return i18n("You have downloads in progress to these destinations: \n\n%1\n\nDelete them and download again?", urlsString);
+            default:
+                return QString();
             }
         }
         if (type == Source) {
             switch (warning) {
-                case ExistingFinishedTransfer:
-                    return i18n("You have already completed downloads from these locations: \n\n%1\n\nDownload them again?", urlsString);
-                case ExistingTransfer:
-                    return i18n("You have downloads in progress from these locations: \n\n%1\n\nDelete them and download again?", urlsString);
-                default:
-                    QString();
+            case ExistingFinishedTransfer:
+                return i18n("You have already completed downloads from these locations: \n\n%1\n\nDownload them again?", urlsString);
+            case ExistingTransfer:
+                return i18n("You have downloads in progress from these locations: \n\n%1\n\nDelete them and download again?", urlsString);
+            default:
+                QString();
             }
         }
     }
@@ -544,15 +544,14 @@ QString UrlChecker::message(const QList<QUrl> &urls, const UrlChecker::UrlType t
     return QString();
 }
 
-
 QList<QUrl> UrlChecker::hasExistingTransferMessages(const QList<QUrl> &urls, const UrlChecker::UrlType type)
 {
     UrlWarning warning;
-    QHash<UrlWarning, QList<QPair<QUrl, TransferHandler*> > > splitWarnings;
+    QHash<UrlWarning, QList<QPair<QUrl, TransferHandler *>>> splitWarnings;
     QList<QUrl> urlsToDownload;
 
-    //collect all errors
-    foreach(const QUrl &url, urls) {
+    // collect all errors
+    foreach (const QUrl &url, urls) {
         TransferHandler *transfer = existingTransfer(url, type, &warning);
         if (transfer) {
             splitWarnings[warning] << qMakePair(url, transfer);
@@ -561,16 +560,16 @@ QList<QUrl> UrlChecker::hasExistingTransferMessages(const QList<QUrl> &urls, con
         }
     }
 
-    //First ask about unfinished existing transfers
-    QList<QPair<QUrl, TransferHandler*> >::const_iterator it;
-    QList<QPair<QUrl, TransferHandler*> >::const_iterator itEnd;
+    // First ask about unfinished existing transfers
+    QList<QPair<QUrl, TransferHandler *>>::const_iterator it;
+    QList<QPair<QUrl, TransferHandler *>>::const_iterator itEnd;
     QList<UrlWarning> orderOfExecution;
-    QList<TransferHandler*> toDelete;
+    QList<TransferHandler *> toDelete;
     orderOfExecution << ExistingTransfer << ExistingFinishedTransfer;
     for (int i = 0; i < orderOfExecution.count(); ++i) {
         warning = orderOfExecution[i];
         if (splitWarnings.contains(warning)) {
-            QList<QPair<QUrl, TransferHandler*> > existing = splitWarnings[warning];
+            QList<QPair<QUrl, TransferHandler *>> existing = splitWarnings[warning];
             itEnd = existing.constEnd();
             bool isYesAll = false;
             bool isNoAll = false;
@@ -592,21 +591,21 @@ QList<QUrl> UrlChecker::hasExistingTransferMessages(const QList<QUrl> &urls, con
                     result = hasExistingDialog(it->first, type, warning);
                 }
                 switch (result) {
-                    case ExistingTransferDialog::ExistingDialogReturn::YesAll:
-                        isYesAll = true;
-                        // fallthrough
-                    case ExistingTransferDialog::ExistingDialogReturn::Yes:
-                        urlsToDownload << it->first;
-                        toDelete << it->second;
-                        break;
-                    case ExistingTransferDialog::ExistingDialogReturn::NoAll:
-                        isNoAll = true;
-                    case ExistingTransferDialog::ExistingDialogReturn::No:
-                        break;
-                    case ExistingTransferDialog::ExistingDialogReturn::Cancel:
-                    default:
-                        removeTransfers(toDelete);
-                        return urlsToDownload;
+                case ExistingTransferDialog::ExistingDialogReturn::YesAll:
+                    isYesAll = true;
+                    // fallthrough
+                case ExistingTransferDialog::ExistingDialogReturn::Yes:
+                    urlsToDownload << it->first;
+                    toDelete << it->second;
+                    break;
+                case ExistingTransferDialog::ExistingDialogReturn::NoAll:
+                    isNoAll = true;
+                case ExistingTransferDialog::ExistingDialogReturn::No:
+                    break;
+                case ExistingTransferDialog::ExistingDialogReturn::Cancel:
+                default:
+                    removeTransfers(toDelete);
+                    return urlsToDownload;
                 }
             }
         }
@@ -616,44 +615,43 @@ QList<QUrl> UrlChecker::hasExistingTransferMessages(const QList<QUrl> &urls, con
     return urlsToDownload;
 }
 
-void UrlChecker::removeTransfers(const QList<TransferHandler*> &toRemove)
+void UrlChecker::removeTransfers(const QList<TransferHandler *> &toRemove)
 {
-    QList<TransferHandler*> transfers = toRemove;
+    QList<TransferHandler *> transfers = toRemove;
     transfers.removeAll(nullptr);
     if (!transfers.isEmpty()) {
         KGet::delTransfers(transfers);
     }
 }
 
-
 int UrlChecker::hasExistingDialog(const QUrl &url, const UrlChecker::UrlType type, const UrlChecker::UrlWarning warning)
 {
     QWidget *parent = KGet::m_mainWindow;
 
-    //getting the caption
+    // getting the caption
     QString caption;
     if (type == Source) {
         switch (warning) {
-            case ExistingFinishedTransfer:
-                caption = i18n("Delete it and download again?");
-                break;
-            case ExistingTransfer:
-                caption = i18n("Download it again?");
-                break;
-            default:
-                break;
+        case ExistingFinishedTransfer:
+            caption = i18n("Delete it and download again?");
+            break;
+        case ExistingTransfer:
+            caption = i18n("Download it again?");
+            break;
+        default:
+            break;
         }
     } else if (type == Destination) {
         switch (warning) {
-            case ExistingFinishedTransfer:
-            case ExistingTransfer:
-                caption = i18n("File already downloaded. Download anyway?");
-                break;
-            case ExistingFile:
-                caption = i18n("File already exists");
-                break;
-            default:
-                break;
+        case ExistingFinishedTransfer:
+        case ExistingTransfer:
+            caption = i18n("File already downloaded. Download anyway?");
+            break;
+        case ExistingFile:
+            caption = i18n("File already exists");
+            break;
+        default:
+            break;
         }
     }
 
@@ -662,7 +660,7 @@ int UrlChecker::hasExistingDialog(const QUrl &url, const UrlChecker::UrlType typ
     return dialog->exec();
 }
 
-///Non static methods following
+/// Non static methods following
 
 void UrlChecker::clear()
 {
@@ -719,7 +717,7 @@ QUrl UrlChecker::checkExistingFile(const QUrl &source, const QUrl &destination)
 {
     QUrl newDestination = destination;
 
-    //any url is ignored
+    // any url is ignored
     if (m_cancel) {
         return QUrl();
     }
@@ -732,11 +730,10 @@ QUrl UrlChecker::checkExistingFile(const QUrl &source, const QUrl &destination)
 
     if (wouldOverwrite(source, destination)) {
         KIO::RenameDialog_Options args = KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Skip | KIO::RenameDialog_Overwrite;
-        QScopedPointer<KIO::RenameDialog> dlg(new KIO::RenameDialog(KGet::m_mainWindow, i18n("File already exists"), source,
-                                    destination, args));
+        QScopedPointer<KIO::RenameDialog> dlg(new KIO::RenameDialog(KGet::m_mainWindow, i18n("File already exists"), source, destination, args));
 
-        ///in the following cases no dialog needs to be shown
-        if (m_skipAll) { //only existing are ignored
+        /// in the following cases no dialog needs to be shown
+        if (m_skipAll) { // only existing are ignored
             return QUrl();
         } else if (m_overwriteAll) {
             FileDeleter::deleteFile(newDestination);
@@ -746,45 +743,43 @@ QUrl UrlChecker::checkExistingFile(const QUrl &source, const QUrl &destination)
             return newDestination;
         }
 
-        ///now show the dialog and look at the result
+        /// now show the dialog and look at the result
         const int result = dlg->exec();
         switch (result) {
-            case KIO::Result_Overwrite: {
-                //delete the file, that way it won't show up in future calls of this method
-                FileDeleter::deleteFile(newDestination);
-                return newDestination;
-            }
-            case KIO::Result_OverwriteAll: {
-
-                //delete the file, that way it won't show up in future calls of this method
-                FileDeleter::deleteFile(newDestination);
-                m_overwriteAll = true;
-                return newDestination;
-            }
-            case KIO::Result_Rename:
-                //call it again, as there is no check on the user input
-                return checkExistingFile(source, dlg->newDestUrl());
-            case KIO::Result_AutoRename:
-                newDestination = dlg->autoDestUrl();
-                m_autoRenameAll = true;
-                return newDestination;
-            case KIO::Result_Skip:
-                return QUrl();
-            case KIO::Result_AutoSkip:
-                m_skipAll = true;
-                return QUrl();
-            case KIO::Result_Cancel:
-                m_cancel = true;
-                return QUrl();
-            default:
-                return QUrl();
+        case KIO::Result_Overwrite: {
+            // delete the file, that way it won't show up in future calls of this method
+            FileDeleter::deleteFile(newDestination);
+            return newDestination;
+        }
+        case KIO::Result_OverwriteAll: {
+            // delete the file, that way it won't show up in future calls of this method
+            FileDeleter::deleteFile(newDestination);
+            m_overwriteAll = true;
+            return newDestination;
+        }
+        case KIO::Result_Rename:
+            // call it again, as there is no check on the user input
+            return checkExistingFile(source, dlg->newDestUrl());
+        case KIO::Result_AutoRename:
+            newDestination = dlg->autoDestUrl();
+            m_autoRenameAll = true;
+            return newDestination;
+        case KIO::Result_Skip:
+            return QUrl();
+        case KIO::Result_AutoSkip:
+            m_skipAll = true;
+            return QUrl();
+        case KIO::Result_Cancel:
+            m_cancel = true;
+            return QUrl();
+        default:
+            return QUrl();
         }
     }
 
     return newDestination;
 }
 
-
 QList<QUrl> UrlChecker::correctUrls() const
 {
     return m_correctUrls;
