@@ -1,21 +1,21 @@
 /***************************************************************************
-*   Copyright (C) 2011 Matthias Fuchs <mat69@gmx.net>                     *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
-***************************************************************************/
+ *   Copyright (C) 2011 Matthias Fuchs <mat69@gmx.net>                     *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+ ***************************************************************************/
 
 #include "schedulertest.h"
 #include "../core/scheduler.h"
@@ -33,7 +33,7 @@ Q_DECLARE_METATYPE(QList<Job::Policy>)
 const int SchedulerTest::NO_LIMIT = 0;
 
 SettingsHelper::SettingsHelper(int limit)
-  : m_oldLimit(Settings::maxConnections())
+    : m_oldLimit(Settings::maxConnections())
 {
     Settings::setMaxConnections(limit);
 }
@@ -44,7 +44,7 @@ SettingsHelper::~SettingsHelper()
 }
 
 TestJob::TestJob(Scheduler *scheduler, JobQueue *parent)
-  : Job(scheduler, parent)
+    : Job(scheduler, parent)
 {
 }
 
@@ -83,7 +83,7 @@ bool TestJob::isWorking() const
 }
 
 TestQueue::TestQueue(Scheduler *scheduler)
-  : JobQueue(scheduler)
+    : JobQueue(scheduler)
 {
 }
 
@@ -104,8 +104,8 @@ void SchedulerTest::testAppendJobs()
     auto *queue = new TestQueue(&scheduler);
     scheduler.addQueue(queue);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
-    QList<TestJob*> jobs;
+    // uses an own list instead of the iterators to make sure that the order stays the same
+    QList<TestJob *> jobs;
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -121,17 +121,25 @@ void SchedulerTest::testAppendJobs()
 void SchedulerTest::testAppendJobs_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
-    QTest::addColumn<QList<Job::Status> >("finalStatus");
+    QTest::addColumn<QList<Job::Status>>("status");
+    QTest::addColumn<QList<Job::Status>>("finalStatus");
 
-    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("limit 2, two finished, will third aborted be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Aborted) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
-    QTest::newRow("limit 2, will first two start while last will be stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
-    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
-    QTest::newRow("no limit, will all three be started and one remain running?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Running << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running << Job::Running);
-} 
+    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+                                                                   << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("limit 2, two finished, will third aborted be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Aborted)
+                                                                           << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+                                                                                 << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
+    QTest::newRow("limit 2, will first two start while last will be stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running)
+                                                                               << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
+    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+                                                                    << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+                                                          << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
+    QTest::newRow("no limit, will all three be started and one remain running?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Running << Job::Stopped << Job::Stopped)
+        << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running << Job::Running);
+}
 
 void SchedulerTest::testCountRunningJobs()
 {
@@ -145,7 +153,7 @@ void SchedulerTest::testCountRunningJobs()
     auto *queue = new TestQueue(&scheduler);
     scheduler.addQueue(queue);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
+    // uses an own list instead of the iterators to make sure that the order stays the same
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -161,15 +169,19 @@ void SchedulerTest::testCountRunningJobs()
 void SchedulerTest::testCountRunningJobs_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
+    QTest::addColumn<QList<Job::Status>>("status");
     QTest::addColumn<int>("numRunningJobs");
 
     QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << 1;
     QTest::newRow("limit 2, two finished, will none be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished) << 0;
-    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << 2;
-    QTest::newRow("limit 2, will first two start while last will be stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running) << 2;
-    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << 1;
-    QTest::newRow("no limit, two finished, will third be started and fourth stay running?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped << Job::Running) << 2;
+    QTest::newRow("limit 2, will first two start while last will stay stopped?")
+        << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << 2;
+    QTest::newRow("limit 2, will first two start while last will be stopped?")
+        << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running) << 2;
+    QTest::newRow("no limit, two finished, will third be started?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << 1;
+    QTest::newRow("no limit, two finished, will third be started and fourth stay running?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped << Job::Running) << 2;
     QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << 3;
 }
 
@@ -184,7 +196,7 @@ void SchedulerTest::testStopScheduler()
     auto *queue = new TestQueue(&scheduler);
     scheduler.addQueue(queue);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
+    // uses an own list instead of the iterators to make sure that the order stays the same
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -194,13 +206,12 @@ void SchedulerTest::testStopScheduler()
     scheduler.stop();
 
     QCOMPARE(scheduler.countRunningJobs(), 0);
-
 }
 
 void SchedulerTest::testStopScheduler_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
+    QTest::addColumn<QList<Job::Status>>("status");
 
     QTest::newRow("limit 2, two finished one stopped") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped);
     QTest::newRow("limit 2, two finished one running") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped);
@@ -223,8 +234,8 @@ void SchedulerTest::testSchedulerStopStart()
     auto *queue = new TestQueue(&scheduler);
     scheduler.addQueue(queue);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
-    QList<TestJob*> jobs;
+    // uses an own list instead of the iterators to make sure that the order stays the same
+    QList<TestJob *> jobs;
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -243,18 +254,23 @@ void SchedulerTest::testSchedulerStopStart()
 void SchedulerTest::testSchedulerStopStart_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
-    QTest::addColumn<QList<Job::Status> >("finalStatus");
+    QTest::addColumn<QList<Job::Status>>("status");
+    QTest::addColumn<QList<Job::Status>>("finalStatus");
 
-    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
-    QTest::newRow("limit 2, will first two start while last will be stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
-    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
-    QTest::newRow("limit 2, two finished, will third stay running?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+                                                                   << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+                                                                                 << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
+    QTest::newRow("limit 2, will first two start while last will be stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running)
+                                                                               << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
+    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+                                                                    << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+                                                          << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
+    QTest::newRow("limit 2, two finished, will third stay running?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running)
+                                                                     << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
 }
 
-
 void SchedulerTest::testSuspendScheduler()
 {
     QFETCH(int, limit);
@@ -268,8 +284,8 @@ void SchedulerTest::testSuspendScheduler()
     scheduler.addQueue(queue);
     scheduler.setIsSuspended(true);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
-    QList<TestJob*> jobs;
+    // uses an own list instead of the iterators to make sure that the order stays the same
+    QList<TestJob *> jobs;
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -277,7 +293,7 @@ void SchedulerTest::testSuspendScheduler()
         jobs << job;
     }
 
-    //scheduler is suspended thus the status has to be same as start status
+    // scheduler is suspended thus the status has to be same as start status
     for (int i = 0; i < status.size(); ++i) {
         QCOMPARE(jobs[i]->status(), status[i]);
     }
@@ -291,17 +307,23 @@ void SchedulerTest::testSuspendScheduler()
 void SchedulerTest::testSuspendScheduler_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
-    QTest::addColumn<QList<Job::Status> >("finalStatus");
-
-    //NOTE Scheduler does not stop jobs, it just prevents new ones from being started
-    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
-    QTest::newRow("limit 2, will first start and second not while last will stay running?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
-    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
-    QTest::newRow("limit 2, two finished, will third stay running?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::addColumn<QList<Job::Status>>("status");
+    QTest::addColumn<QList<Job::Status>>("finalStatus");
 
+    // NOTE Scheduler does not stop jobs, it just prevents new ones from being started
+    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+                                                                   << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("limit 2, will first two start while last will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+                                                                                 << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
+    QTest::newRow("limit 2, will first start and second not while last will stay running?")
+        << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Running)
+        << (QList<Job::Status>() << Job::Running << Job::Running << Job::Stopped);
+    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+                                                                    << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+                                                          << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
+    QTest::newRow("limit 2, two finished, will third stay running?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running)
+                                                                     << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
 }
 
 void SchedulerTest::testJobQueueStopPolicy()
@@ -318,8 +340,8 @@ void SchedulerTest::testJobQueueStopPolicy()
     queue->setStatus(JobQueue::Stopped);
     scheduler.addQueue(queue);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
-    QList<TestJob*> jobs;
+    // uses an own list instead of the iterators to make sure that the order stays the same
+    QList<TestJob *> jobs;
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -336,15 +358,26 @@ void SchedulerTest::testJobQueueStopPolicy()
 void SchedulerTest::testJobQueueStopPolicy_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
-    QTest::addColumn<QList<Job::Status> >("finalStatus");
-    QTest::addColumn<QList<Job::Policy> >("policy");
+    QTest::addColumn<QList<Job::Status>>("status");
+    QTest::addColumn<QList<Job::Status>>("finalStatus");
+    QTest::addColumn<QList<Job::Policy>>("policy");
 
-    QTest::newRow("limit 2, two finished, will third not be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Policy>() << Job::None << Job::None << Job::None);
-    QTest::newRow("limit 2, will first start while rest will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Stopped) << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::None);
-    QTest::newRow("limit 2, will first and third start while rest will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running << Job::Stopped) << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::Start << Job::None);
-    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::None << Job::Start);
-    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::Start << Job::Start);
+    QTest::newRow("limit 2, two finished, will third not be started?")
+        << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+        << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Policy>() << Job::None << Job::None << Job::None);
+    QTest::newRow("limit 2, will first start while rest will stay stopped?")
+        << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Stopped)
+        << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::None);
+    QTest::newRow("limit 2, will first and third start while rest will stay stopped?")
+        << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped << Job::Stopped)
+        << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running << Job::Stopped)
+        << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::Start << Job::None);
+    QTest::newRow("no limit, two finished, will third be started?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+        << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::None << Job::Start);
+    QTest::newRow("no limit, will all three be started?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+        << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::Start << Job::Start);
 }
 
 void SchedulerTest::testJobQueueStopStartPolicy()
@@ -362,8 +395,8 @@ void SchedulerTest::testJobQueueStopStartPolicy()
     queue->setStatus(JobQueue::Stopped);
     scheduler.addQueue(queue);
 
-    //uses an own list instead of the iterators to make sure that the order stays the same
-    QList<TestJob*> jobs;
+    // uses an own list instead of the iterators to make sure that the order stays the same
+    QList<TestJob *> jobs;
     for (int i = 0; i < status.size(); ++i) {
         auto *job = new TestJob(&scheduler, queue);
         job->setStatus(status[i]);
@@ -380,23 +413,37 @@ void SchedulerTest::testJobQueueStopStartPolicy()
 
     for (int i = 0; i < status.size(); ++i) {
         QCOMPARE(jobs[i]->status(), finalStatus[i]);
-
     }
 }
 
 void SchedulerTest::testJobQueueStopStartPolicy_data()
 {
     QTest::addColumn<int>("limit");
-    QTest::addColumn<QList<Job::Status> >("status");
-    QTest::addColumn<QList<Job::Status> >("intermediateStatus");
-    QTest::addColumn<QList<Job::Policy> >("policy");
-    QTest::addColumn<QList<Job::Status> >("finalStatus");
+    QTest::addColumn<QList<Job::Status>>("status");
+    QTest::addColumn<QList<Job::Status>>("intermediateStatus");
+    QTest::addColumn<QList<Job::Policy>>("policy");
+    QTest::addColumn<QList<Job::Status>>("finalStatus");
 
-    QTest::newRow("limit 2, two finished, will third be started?") << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Policy>() << Job::None << Job::None << Job::None) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("limit 2, will first and last start while rest will stay stopped?") << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Stopped) << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::None) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running);
-    QTest::newRow("limit 3, will first, third and last start while rest will stay stopped?") << 3 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running << Job::Stopped) << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::Start << Job::None) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running << Job::Running);
-    QTest::newRow("no limit, two finished, will third be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::Start << Job::Start) << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
-    QTest::newRow("no limit, will all three be started?") << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::Start << Job::Start) << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
+    QTest::newRow("limit 2, two finished, will third be started?")
+        << 2 << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+        << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped) << (QList<Job::Policy>() << Job::None << Job::None << Job::None)
+        << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("limit 2, will first and last start while rest will stay stopped?")
+        << 2 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Stopped)
+        << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::None) << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running);
+    QTest::newRow("limit 3, will first, third and last start while rest will stay stopped?")
+        << 3 << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped << Job::Stopped)
+        << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running << Job::Stopped)
+        << (QList<Job::Policy>() << Job::Start << Job::Stop << Job::Start << Job::None)
+        << (QList<Job::Status>() << Job::Running << Job::Stopped << Job::Running << Job::Running);
+    QTest::newRow("no limit, two finished, will third be started?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Stopped)
+        << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::Start << Job::Start)
+        << (QList<Job::Status>() << Job::Finished << Job::Finished << Job::Running);
+    QTest::newRow("no limit, will all three be started?")
+        << NO_LIMIT << (QList<Job::Status>() << Job::Stopped << Job::Stopped << Job::Stopped)
+        << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running) << (QList<Job::Policy>() << Job::Start << Job::Start << Job::Start)
+        << (QList<Job::Status>() << Job::Running << Job::Running << Job::Running);
 }
 
 void SchedulerTest::testJobErrorType()
@@ -466,7 +513,7 @@ void SchedulerTest::testGettingNetworkConnection()
 
     scheduler.setHasNetworkConnection(true);
 
-    QCOMPARE(job->policy(), policy);//the policy should remain unchanged
+    QCOMPARE(job->policy(), policy); // the policy should remain unchanged
     QCOMPARE(job->status(), finalStatus);
 }
 
@@ -497,7 +544,7 @@ void SchedulerTest::testLosingNetworkConnection()
 
     scheduler.setHasNetworkConnection(false);
 
-    QCOMPARE(job->policy(), policy);//the policy should remain unchanged
+    QCOMPARE(job->policy(), policy); // the policy should remain unchanged
     QCOMPARE(job->status(), Job::Stopped);
 }
 
@@ -522,7 +569,7 @@ void SchedulerTest::testShouldUpdate()
     auto *queue = new TestQueue(&scheduler);
     scheduler.addQueue(queue);
 
-    QVERIFY(scheduler.shouldUpdate());//should be true by default
+    QVERIFY(scheduler.shouldUpdate()); // should be true by default
 
     scheduler.setIsSuspended(isSuspended);
     scheduler.setHasNetworkConnection(hasNetworkConnection);
@@ -542,5 +589,3 @@ void SchedulerTest::testShouldUpdate_data()
 }
 
 QTEST_MAIN(SchedulerTest)
-
-
