@@ -1,21 +1,21 @@
 /***************************************************************************
-*   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>                     *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
-***************************************************************************/
+ *   Copyright (C) 2009 Matthias Fuchs <mat69@gmx.net>                     *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+ ***************************************************************************/
 
 #include "checksumsearch.h"
 
@@ -30,19 +30,18 @@
 const QStringList ChecksumSearch::URLCHANGEMODES = (QStringList() << i18n("Append") << i18n("Replace file") << i18n("Replace file-ending"));
 
 ChecksumSearch::ChecksumSearch(const QList<QUrl> &srcs, const QString &fileName, const QStringList &types, QObject *parent)
-  : QObject(parent),
-    m_copyJob(nullptr),
-    m_srcs(srcs),
-    m_fileName(fileName),
-    m_types(types)
+    : QObject(parent)
+    , m_copyJob(nullptr)
+    , m_srcs(srcs)
+    , m_fileName(fileName)
+    , m_types(types)
 {
     createDownload();
 }
 
 ChecksumSearch::~ChecksumSearch()
 {
-    if (m_copyJob)
-    {
+    if (m_copyJob) {
         m_copyJob->kill(KJob::Quietly);
     }
 }
@@ -80,18 +79,17 @@ void ChecksumSearch::slotResult(KJob *job)
 
     m_data.clear();
 
-    switch (job->error())
+    switch (job->error()) {
+    case 0: // The download has finished
     {
-        case 0://The download has finished
-        {
-            qCDebug(KGET_DEBUG) << "Correctly downloaded" << m_src.toDisplayString();
-            m_data = QString(m_dataBA);
-            break;
-        }
+        qCDebug(KGET_DEBUG) << "Correctly downloaded" << m_src.toDisplayString();
+        m_data = QString(m_dataBA);
+        break;
+    }
 
-        default:
-            qCDebug(KGET_DEBUG) << "There was error" << job->error() << "while downloading" << m_src.toDisplayString();
-            break;
+    default:
+        qCDebug(KGET_DEBUG) << "There was error" << job->error() << "while downloading" << m_src.toDisplayString();
+        break;
     }
 
     m_copyJob = nullptr;
@@ -106,7 +104,7 @@ void ChecksumSearch::parseDownload()
         qCDebug(KGET_DEBUG) << "*******Parse*******\n" << m_data << "*******************";
     }
 
-    //no type has been specified
+    // no type has been specified
     if (m_type.isEmpty()) {
         parseDownloadEmpty();
         return;
@@ -118,7 +116,7 @@ void ChecksumSearch::parseDownload()
     QRegExp rxChecksum(patternChecksum);
     QString hash;
 
-    //find the correct line
+    // find the correct line
     const QStringList lines = m_data.split('\n');
     foreach (const QString &line, lines) {
         if (line.contains(m_fileName, Qt::CaseInsensitive)) {
@@ -132,7 +130,7 @@ void ChecksumSearch::parseDownload()
         }
     }
 
-    //nothing found yet, so simply search for a word in the whole data that has the correct length
+    // nothing found yet, so simply search for a word in the whole data that has the correct length
     if (hash.isEmpty() && (rxChecksum.indexIn(m_data) > -1)) {
         QString hash = rxChecksum.cap(0);
         if (!m_fileName.contains(hash, Qt::CaseInsensitive)) {
@@ -141,7 +139,7 @@ void ChecksumSearch::parseDownload()
         }
     }
 
-    //only create a download here if type was specified, otherwise parseDownloadEmpty has to handle this
+    // only create a download here if type was specified, otherwise parseDownloadEmpty has to handle this
     if (!m_isEmpty) {
         createDownload();
     }
@@ -151,10 +149,8 @@ void ChecksumSearch::parseDownloadEmpty()
 {
     const QStringList lines = m_data.split('\n');
     const QStringList supportedTypes = Verifier::supportedVerficationTypes();
-    foreach (const QString &type, supportedTypes)
-    {
-        if (m_data.contains(type, Qt::CaseInsensitive))
-        {
+    foreach (const QString &type, supportedTypes) {
+        if (m_data.contains(type, Qt::CaseInsensitive)) {
             m_type = type;
             parseDownload();
         }
@@ -165,28 +161,21 @@ void ChecksumSearch::parseDownloadEmpty()
 
 QUrl ChecksumSearch::createUrl(const QUrl &src, const QString &change, ChecksumSearch::UrlChangeMode mode)
 {
-    if (!src.isValid() || change.isEmpty())
-    {
+    if (!src.isValid() || change.isEmpty()) {
         return QUrl();
     }
 
     QUrl url;
-    if (mode == kg_Append)
-    {
+    if (mode == kg_Append) {
         url = QUrl(src.toString() + change);
-    }
-    else if (mode == kg_ReplaceFile)
-    {
+    } else if (mode == kg_ReplaceFile) {
         QUrl temp = src.adjusted(QUrl::RemoveFilename);
         temp.setPath(temp.path() + change);
         url = temp;
-    }
-    else if (mode == kg_ReplaceEnding)
-    {
+    } else if (mode == kg_ReplaceEnding) {
         QString fileName = src.fileName();
         int index = fileName.lastIndexOf('.');
-        if (index > -1)
-        {
+        if (index > -1) {
             fileName = fileName.left(index) + change;
             QUrl temp = src.adjusted(QUrl::RemoveFilename);
             temp.setPath(temp.path() + fileName);
@@ -196,5 +185,3 @@ QUrl ChecksumSearch::createUrl(const QUrl &src, const QString &change, ChecksumS
 
     return url;
 }
-
-
