@@ -13,37 +13,40 @@
 
 #include "abstractmetalink.h"
 
-#include "core/kget.h"
-#include "core/transfergroup.h"
 #include "core/download.h"
-#include "core/transferdatasource.h"
 #include "core/filemodel.h"
+#include "core/kget.h"
+#include "core/signature.h"
+#include "core/transferdatasource.h"
+#include "core/transfergroup.h"
 #include "core/urlchecker.h"
 #include "core/verifier.h"
-#include "core/signature.h"
 
 #include "kget_debug.h"
 
-#include <kwidgetsaddons_version.h>
 #include <KIO/DeleteJob>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <kwidgetsaddons_version.h>
 
 #include <QDialog>
-#include <QFile>
 #include <QDomElement>
+#include <QFile>
 
-AbstractMetalink::AbstractMetalink(TransferGroup * parent, TransferFactory * factory,
-                         Scheduler * scheduler, const QUrl & source, const QUrl & dest,
-                         const QDomElement * e)
-    : Transfer(parent, factory, scheduler, source, dest, e),
-      m_fileModel(nullptr),
-      m_currentFiles(),
-      m_ready(false),
-      m_speedCount(0),
-      m_tempAverageSpeed(0),
-      m_averageSpeed(0)
+AbstractMetalink::AbstractMetalink(TransferGroup *parent,
+                                   TransferFactory *factory,
+                                   Scheduler *scheduler,
+                                   const QUrl &source,
+                                   const QUrl &dest,
+                                   const QDomElement *e)
+    : Transfer(parent, factory, scheduler, source, dest, e)
+    , m_fileModel(nullptr)
+    , m_currentFiles()
+    , m_ready(false)
+    , m_speedCount(0)
+    , m_tempAverageSpeed(0)
+    , m_averageSpeed(0)
 {
 }
 
@@ -54,7 +57,7 @@ AbstractMetalink::~AbstractMetalink()
 void AbstractMetalink::slotDataSourceFactoryChange(Transfer::ChangesFlags change)
 {
     if ((change & Tc_Status) | (change & Tc_TotalSize)) {
-        auto *factory = qobject_cast<DataSourceFactory*>(sender());
+        auto *factory = qobject_cast<DataSourceFactory *>(sender());
         if (change & Tc_Status) {
             bool changeStatus;
             updateStatus(factory, &changeStatus);
@@ -103,12 +106,9 @@ void AbstractMetalink::recalculateProcessedSize()
         }
     }
 
-    if (m_totalSize)
-    {
+    if (m_totalSize) {
         m_percent = (m_downloadedSize * 100) / m_totalSize;
-    }
-    else
-    {
+    } else {
         m_percent = 0;
     }
 }
@@ -122,7 +122,7 @@ void AbstractMetalink::recalculateSpeed()
         }
     }
 
-    //calculate the average of the last three speeds
+    // calculate the average of the last three speeds
     m_tempAverageSpeed += m_downloadSpeed;
     ++m_speedCount;
     if (m_speedCount == 3) {
@@ -144,46 +144,45 @@ void AbstractMetalink::updateStatus(DataSourceFactory *sender, bool *changeStatu
 {
     Job::Status status = (sender ? sender->status() : Job::Stopped);
     *changeStatus = true;
-    switch (status)
-    {
-        case Job::Aborted:
-        case Job::Stopped: {
-            m_currentFiles = 0;
-            foreach (DataSourceFactory *factory, m_dataSourceFactory) {
-                //one factory is still running, do not change the status
-                if (factory->doDownload() && (factory->status() == Job::Running)) {
-                    *changeStatus = false;
-                    ++m_currentFiles;
-                }
+    switch (status) {
+    case Job::Aborted:
+    case Job::Stopped: {
+        m_currentFiles = 0;
+        foreach (DataSourceFactory *factory, m_dataSourceFactory) {
+            // one factory is still running, do not change the status
+            if (factory->doDownload() && (factory->status() == Job::Running)) {
+                *changeStatus = false;
+                ++m_currentFiles;
             }
-
-            if (*changeStatus) {
-                setStatus(status);
-            }
-            break;
         }
-        case Job::Finished:
-            //one file that has been downloaded now is finished//FIXME ignore downloads that were finished in the previous download!!!!
-            if (m_currentFiles) {
-                --m_currentFiles;
-                startMetalink();
-            }
-            foreach (DataSourceFactory *factory, m_dataSourceFactory) {
-                //one factory is not finished, do not change the status
-                if (factory->doDownload() && (factory->status() != Job::Finished)) {
-                    *changeStatus = false;
-                    break;
-                }
-            }
 
-            if (*changeStatus) {
-                setStatus(Job::Finished);
-            }
-            break;
-
-        default:
+        if (*changeStatus) {
             setStatus(status);
-            break;
+        }
+        break;
+    }
+    case Job::Finished:
+        // one file that has been downloaded now is finished//FIXME ignore downloads that were finished in the previous download!!!!
+        if (m_currentFiles) {
+            --m_currentFiles;
+            startMetalink();
+        }
+        foreach (DataSourceFactory *factory, m_dataSourceFactory) {
+            // one factory is not finished, do not change the status
+            if (factory->doDownload() && (factory->status() != Job::Finished)) {
+                *changeStatus = false;
+                break;
+            }
+        }
+
+        if (*changeStatus) {
+            setStatus(Job::Finished);
+        }
+        break;
+
+    default:
+        setStatus(status);
+        break;
     }
 
     if (m_fileModel) {
@@ -198,9 +197,8 @@ void AbstractMetalink::slotVerified(bool isVerified)
 {
     Q_UNUSED(isVerified)
 
-    if (status() == Job::Finished)
-    {
-        //see if some files are NotVerified
+    if (status() == Job::Finished) {
+        // see if some files are NotVerified
         QStringList brokenFiles;
         foreach (DataSourceFactory *factory, m_dataSourceFactory) {
             if (m_fileModel) {
@@ -212,15 +210,17 @@ void AbstractMetalink::slotVerified(bool isVerified)
             }
         }
 
-        if (brokenFiles.count())
-        {
+        if (brokenFiles.count()) {
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-            if (KMessageBox::warningTwoActionsList(nullptr,
+            if (KMessageBox::warningTwoActionsList(
+                    nullptr,
 #else
-            if (KMessageBox::warningYesNoList(nullptr,
+            if (KMessageBox::warningYesNoList(
+                    nullptr,
 #endif
                     i18n("The download could not be verified, do you want to repair (if repairing does not work the download would be restarted) it?"),
-                    brokenFiles, QString(),
+                    brokenFiles,
+                    QString(),
                     KGuiItem(i18nc("@action:button", "Repair")),
                     KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
@@ -238,9 +238,8 @@ void AbstractMetalink::slotVerified(bool isVerified)
 
 void AbstractMetalink::slotSignatureVerified()
 {
-    if (status() == Job::Finished)
-    {
-        //see if some files are NotVerified
+    if (status() == Job::Finished) {
+        // see if some files are NotVerified
         QStringList brokenFiles;
         foreach (DataSourceFactory *factory, m_dataSourceFactory) {
             if (m_fileModel) {
@@ -251,19 +250,19 @@ void AbstractMetalink::slotSignatureVerified()
                 brokenFiles.append(factory->dest().toString());
             }
         }
-/*
-        if (brokenFiles.count())//TODO
-        {
-            if (KMessageBox::warningYesNoCancelList(0,
-                i18n("The download could not be verified, try to repair it?"),
-                     brokenFiles) == KMessageBox::Yes)
-            {
-                if (repair())
+        /*
+                if (brokenFiles.count())//TODO
                 {
-                    return;
-                }
-            }
-        }*/
+                    if (KMessageBox::warningYesNoCancelList(0,
+                        i18n("The download could not be verified, try to repair it?"),
+                             brokenFiles) == KMessageBox::Yes)
+                    {
+                        if (repair())
+                        {
+                            return;
+                        }
+                    }
+                }*/
     }
 }
 
@@ -277,9 +276,8 @@ bool AbstractMetalink::repair(const QUrl &file)
                 return true;
             }
         }
-    }
-    else {
-        QList<DataSourceFactory*> broken;
+    } else {
+        QList<DataSourceFactory *> broken;
         foreach (DataSourceFactory *factory, m_dataSourceFactory) {
             if (factory->doDownload() && (factory->verifier()->status() == Verifier::NotVerified)) {
                 broken.append(factory);
@@ -296,7 +294,6 @@ bool AbstractMetalink::repair(const QUrl &file)
     return false;
 }
 
-
 Verifier *AbstractMetalink::verifier(const QUrl &file)
 {
     if (!m_dataSourceFactory.contains(file)) {
@@ -324,7 +321,7 @@ FileModel *AbstractMetalink::fileModel()
 {
     if (!m_fileModel) {
         m_fileModel = new FileModel(files(), directory(), this);
-        connect(m_fileModel, SIGNAL(rename(QUrl,QUrl)), this, SLOT(slotRename(QUrl,QUrl)));
+        connect(m_fileModel, SIGNAL(rename(QUrl, QUrl)), this, SLOT(slotRename(QUrl, QUrl)));
         connect(m_fileModel, &FileModel::checkStateChanged, this, &AbstractMetalink::filesSelected);
 
         foreach (DataSourceFactory *factory, m_dataSourceFactory) {
@@ -337,8 +334,7 @@ FileModel *AbstractMetalink::fileModel()
             m_fileModel->setData(checksumVerified, factory->verifier()->status());
             QModelIndex signatureVerified = m_fileModel->index(dest, FileItem::SignatureVerified);
             m_fileModel->setData(signatureVerified, factory->signature()->status());
-            if (!factory->doDownload())
-            {
+            if (!factory->doDownload()) {
                 QModelIndex index = m_fileModel->index(factory->dest(), FileItem::File);
                 m_fileModel->setData(index, Qt::Unchecked, Qt::CheckStateRole);
             }
@@ -377,7 +373,7 @@ bool AbstractMetalink::setDirectory(const QUrl &new_directory)
     m_dest = new_directory;
     m_dest.setPath(m_dest.adjusted(QUrl::RemoveFilename).toString() + fileName);
 
-    QHash<QUrl, DataSourceFactory*> newStorage;
+    QHash<QUrl, DataSourceFactory *> newStorage;
     foreach (DataSourceFactory *factory, m_dataSourceFactory) {
         const QUrl oldUrl = factory->dest();
         const QUrl newUrl = QUrl(oldUrl.toString().replace(oldDirectory, newDirectory));
@@ -390,9 +386,9 @@ bool AbstractMetalink::setDirectory(const QUrl &new_directory)
     return true;
 }
 
-QHash<QUrl, QPair<bool, int> > AbstractMetalink::availableMirrors(const QUrl &file) const
+QHash<QUrl, QPair<bool, int>> AbstractMetalink::availableMirrors(const QUrl &file) const
 {
-    QHash<QUrl, QPair<bool, int> > urls;
+    QHash<QUrl, QPair<bool, int>> urls;
 
     if (m_dataSourceFactory.contains(file)) {
         urls = m_dataSourceFactory[file]->mirrors();
@@ -401,8 +397,7 @@ QHash<QUrl, QPair<bool, int> > AbstractMetalink::availableMirrors(const QUrl &fi
     return urls;
 }
 
-
-void AbstractMetalink::setAvailableMirrors(const QUrl &file, const QHash<QUrl, QPair<bool, int> > &mirrors)
+void AbstractMetalink::setAvailableMirrors(const QUrl &file, const QHash<QUrl, QPair<bool, int>> &mirrors)
 {
     if (!m_dataSourceFactory.contains(file)) {
         return;
@@ -416,7 +411,7 @@ void AbstractMetalink::slotUpdateCapabilities()
     Capabilities oldCap = capabilities();
     Capabilities newCap = {};
     foreach (DataSourceFactory *file, m_dataSourceFactory) {
-        if (file->doDownload()) {//FIXME when a download did not start yet it should be moveable!!//FIXME why not working, when only two connections?
+        if (file->doDownload()) { // FIXME when a download did not start yet it should be moveable!!//FIXME why not working, when only two connections?
             if (newCap) {
                 newCap &= file->capabilities();
             } else {
@@ -442,15 +437,15 @@ void AbstractMetalink::untickAllFiles()
 
 void AbstractMetalink::fileDlgFinished(int result)
 {
-    //the dialog was not accepted untick every file, this ensures that the user does not
-    //press start by accident without first selecting the desired files
+    // the dialog was not accepted untick every file, this ensures that the user does not
+    // press start by accident without first selecting the desired files
     if (result != QDialog::Accepted) {
         untickAllFiles();
     }
 
     filesSelected();
 
-    //no files selected to download or dialog rejected, stop the download
+    // no files selected to download or dialog rejected, stop the download
     if (!m_numFilesSelected || (result != QDialog::Accepted)) {
         setStatus(Job::Stopped);
         setTransferChange(Tc_Status, true);
@@ -468,35 +463,36 @@ void AbstractMetalink::filesSelected()
     QModelIndexList files = fileModel()->fileIndexes(FileItem::File);
     m_numFilesSelected = 0;
 
-    //sets the CheckState of the fileModel to the according DataSourceFactories
-    //and asks the user if there are existing files already
-    foreach (const QModelIndex &index, files)
-    {
+    // sets the CheckState of the fileModel to the according DataSourceFactories
+    // and asks the user if there are existing files already
+    foreach (const QModelIndex &index, files) {
         const QUrl dest = fileModel()->getUrl(index);
         bool doDownload = index.data(Qt::CheckStateRole).toBool();
-        if (m_dataSourceFactory.contains(dest))
-        {
+        if (m_dataSourceFactory.contains(dest)) {
             DataSourceFactory *factory = m_dataSourceFactory[dest];
-            //ignore finished transfers
+            // ignore finished transfers
             if ((factory->status() == Job::Finished) || (factory->status() == Job::FinishedKeepAlive)) {
                 continue;
             }
 
-            //check if the file at dest exists already and ask the user what to do in this case, ignore already running transfers
+            // check if the file at dest exists already and ask the user what to do in this case, ignore already running transfers
             if (doDownload && (factory->status() != Job::Running) && QFile::exists(dest.toLocalFile())) {
-                //user has chosen to skip all files that exist already before
+                // user has chosen to skip all files that exist already before
                 if (autoSkip) {
                     fileModel()->setData(index, Qt::Unchecked, Qt::CheckStateRole);
                     doDownload = false;
-                //ask the user, unless he has chosen overwriteAll before
+                    // ask the user, unless he has chosen overwriteAll before
                 } else if (!overwriteAll) {
-                    KIO::RenameDialog dlg(nullptr, i18n("File already exists"), QUrl(index.data().toString()), dest,
+                    KIO::RenameDialog dlg(nullptr,
+                                          i18n("File already exists"),
+                                          QUrl(index.data().toString()),
+                                          dest,
                                           KIO::RenameDialog_Options(KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Overwrite | KIO::RenameDialog_Skip));
                     const int result = dlg.exec();
 
                     if (result == KIO::Result_Rename) {
-                        //no reason to use FileModel::rename() since the file does not exist yet, so simply skip it
-                        //avoids having to deal with signals
+                        // no reason to use FileModel::rename() since the file does not exist yet, so simply skip it
+                        // avoids having to deal with signals
                         const QUrl newDest = dlg.newDestUrl();
                         factory->setDoDownload(doDownload);
                         factory->setNewDestination(newDest);
@@ -529,7 +525,7 @@ void AbstractMetalink::filesSelected()
         }
     }
 
-    //the user decided to cancel, so untick all files
+    // the user decided to cancel, so untick all files
     if (cancel) {
         m_numFilesSelected = 0;
         untickAllFiles();
@@ -539,7 +535,7 @@ void AbstractMetalink::filesSelected()
     }
 
     Transfer::ChangesFlags change = (Tc_TotalSize | Tc_DownloadSpeed);
-    //some files have been selected that are not finished yet, set them to stop if the transfer is not running (checked in slotStatus)
+    // some files have been selected that are not finished yet, set them to stop if the transfer is not running (checked in slotStatus)
     if (m_numFilesSelected) {
         change |= Tc_Status;
     }
@@ -549,15 +545,10 @@ void AbstractMetalink::filesSelected()
 void AbstractMetalink::stop()
 {
     qCDebug(KGET_DEBUG) << "metalink::Stop";
-    if (m_ready && ((status() != Stopped) || (status() != Finished)))
-    {
+    if (m_ready && ((status() != Stopped) || (status() != Finished))) {
         m_currentFiles = 0;
-        foreach (DataSourceFactory *factory, m_dataSourceFactory)
-        {
+        foreach (DataSourceFactory *factory, m_dataSourceFactory) {
             factory->stop();
         }
     }
 }
-
-
-
